@@ -16,7 +16,7 @@ impl DemoDialog {
 
 impl Dialog for DemoDialog {
     fn attributes(&self) -> Attributes {
-        Attributes::new(WS_NORMAL, "Demo Dialog".to_string(), 320, 250, 50, 50)
+        Attributes::new(WS_NORMAL, "Demo Dialog".to_string(), "io.github.lattesyobon.demo".to_string(),320, 250, 50, 50)
     }
 
     fn frame(&self) -> Frame {
